icsemantic.catalog.config

Package platecom :: Package ontocatalog :: Module config |
[hide private]
[frames] | no frames]

# Source Code for Module icsemantic.catalog.config

     1  """Global constants for OntoCatalog.
     2  """
     3
     4  GLOBALS = globals()
     5  try:
     6      import Products.CMFPlone.migrations.v3_0
     7      HAS_PLONE3 = True
     8  except ImportError:
     9      HAS_PLONE3 = False
    10
    11  import platecom.ontocatalog
    12  PROJECTNAME = "icsemantic.catalog"
    13  PACKAGE = platecom.ontocatalog
    14  PACKAGENAME = "icsemantic.catalog"
    15  DEPENDENCIES = ['LinguaPlone', 'pluggablecatalog', 'icsemantic.langfallback', 'icsemantic.thesaurus']
    16
    17  SYNONYM_IDX = 'SearchableSynonymousText'
    18  TRANSLATION_IDX = 'SearchableTranslatedText'
    19  RELATED_IDX = 'SearchableRelatedText'
    20